# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject1
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/2 20:25
# Description:
# #号开头的代码表示注释信息
# ---------------------------------------------------------------------------
import openpyxl

from homewoke.接口pytest框架.file_data.settings import *
from homewoke.接口自动化框架_登录_添加维度.common.read_ini import ReadIni
from homewoke.接口自动化框架_登录_添加维度.common.read_json import read_json


class ReadExcel:
    def __init__(self):
        # 获取所有的json文件的路径, 使用ReadIni对象调用get_file_path获取文件的路径
        self.read_ini = ReadIni()
        case_data_path = self.read_ini.get_file_path("case")
        expect_data_path = self.read_ini.get_file_path("expect")
        sql_data_path = self.read_ini.get_file_path("sql")
        # 调用read_json函数读取所有的json文件
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)
        # 读取Excel
        self.excel_path = self.read_ini.get_file_path("excel")
        self.wb = openpyxl.load_workbook(self.excel_path)
        table_name = self.read_ini.get_table_name("table")
        self.ws = self.wb[table_name]

    # 将WS中的单元格数据设置为私有属性可以用关键字参数传参
    def __get_cell_value(self, column: str, row: int) -> str:
        value = self.ws[str(column)+str(row)].value
        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def module_name(self, row):
        return self.__get_cell_value(MODULE, row)

    def interface_name(self,row):
        return self.__get_cell_value(API, row)

    def case_title(self, row):
        return self.__get_cell_value(TITLE, row)

    def case_level(self, row):
        return self.__get_cell_value(LEVEL, row)

    def case_method(self, row):
        return self.__get_cell_value(PATH, row)

    def case_url(self,row):
        host = self.read_ini.get_host(TEST_IP)
        path = self.__get_cell_value(METHOD, row)
        return host + path

    def case_mime(self,row):
        value = self.__get_cell_value(MIME, row)
        if value:
            return value.lower()

    def case_data(self,row):
        case_data_key = self.__get_cell_value(CASEDATA , row)
        if case_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][case_data_key]

    def expect_data(self, row):
        expect_data_key = self.__get_cell_value(EXPECTDATA, row)
        if expect_data_key:
             module_name = self.module_name(row)
             interface_name = self.interface_name(row)
             return self.expect_data_dict[module_name][interface_name][expect_data_key]

    def sql_type(self,row):
        value = self.__get_cell_value(SQLTYPE, row)
        if value:
            return value.lower()

    def sql_sentence(self,row):
        sql_data_key = self.__get_cell_value(SQLSENTENCE, row)

        if sql_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][sql_data_key]

    def update_key(self,row):
        update_key_value = self.__get_cell_value(UPDATEKEY, row)
        if update_key_value:
            return update_key_value

    def get_data(self):
        list_data= []
        for i in range(2,self.ws.max_row +1):
            module = self.module_name(i)
            interface = self.interface_name(i)
            title = self.case_title(i)
            level = self.case_level(i)
            method = self.case_method(i)
            url = self.case_url(i)
            mime = self.case_mime(i)
            case_data = self.case_data(i)
            expect_data = self.expect_data(i)
            sql_type = self.sql_type(i)
            sql_sentence = self.sql_sentence(i)
            update_key = self.update_key(i)
            list_data.append([module,interface, title, level, method, url, mime, case_data, expect_data, sql_type, sql_sentence, update_key, i])
            print([method, url, mime, case_data, expect_data, sql_type, sql_sentence, update_key, i])
            print(type(i))
        else:
            return list_data

    def write_result(self, result, row):
        self.ws[RESULT+str(row)].value = result
        self.wb.save(self.excel_path)


if __name__ == '__main__':
    read_excel = ReadExcel()
    read_excel.get_data()










